@@ -222,6 +222,9 @@ def _update_article(article_id, request):
             dbsession.add(tag)
             
         transaction.commit()
+
+        # force update of tags cloud
+        h.get_public_tags_cloud(force_reload=True)
         
         return HTTPFound(location=route_url('blog_go_article', request, article_id=article_id))
     else:
@@ -300,6 +303,9 @@ def write_article(request):
                 dbsession.add(tag)
                 
             transaction.commit()
+
+            # force update of tags cloud
+            h.get_public_tags_cloud(force_reload=True)
             
             return HTTPFound(location=route_url('blog_go_article', request, article_id=article_id))
             
@@ -836,7 +842,7 @@ def download_file(request):
     except IOError:
         return HTTPNotFound()
     
-    response = Response(content_type=file.content_type)
+    response = Response(content_type=str(file.content_type))
     try:
         response.app_iter = open(full_path, 'rb')
     except IOError:
